//Source file: TerminalCapabilityScopeType.java
//Date: March 2007
//Terminal Capability Interfaces and Data Types for 3GPP TS 29.198-07 V7.0.0

package org.csapi.jr.se.termcap;

/**
 * Defines a specific type of the terminal capability scope definition.
 *
 */
public final class TerminalCapabilityScopeType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static TerminalCapabilityScopeType[] _array = new TerminalCapabilityScopeType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private TerminalCapabilityScopeType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined.
     */
    public static final int _TERMINAL_CAPABILITY_SCOPE_TYPE_UNDEFINED =  0;

    /**
     * Undefined.
     */
    public static final TerminalCapabilityScopeType TERMINAL_CAPABILITY_SCOPE_TYPE_UNDEFINED = new TerminalCapabilityScopeType(_TERMINAL_CAPABILITY_SCOPE_TYPE_UNDEFINED);

    /**
     * Indicates that the terminal capability scope is expressed as CC/PP headers as specified in W3C (see [6] in ES 203 915-1) and adopted in the WAP UAProf specification (see [9] in 
ES 203 915-1). It contains URLs; terminal attributes and values, in RDF format; or a combination of both.
     */
    public static final int _TERMINAL_CAPABILITY_SCOPE_TYPE_CCPP =  1;

    /**
     * Indicates that the terminal capability scope is expressed as CC/PP headers as specified in W3C (see [6] in ES 203 915-1) and adopted in the WAP UAProf specification (see [9] in 
ES 203 915-1). It contains URLs; terminal attributes and values, in RDF format; or a combination of both.
     */
    public static final TerminalCapabilityScopeType TERMINAL_CAPABILITY_SCOPE_TYPE_CCPP = new TerminalCapabilityScopeType(_TERMINAL_CAPABILITY_SCOPE_TYPE_CCPP);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved TerminalCapabilityScopeType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the TerminalCapabilityScopeType object
     */
    public String getValueText() {
        switch (_value) {
            case _TERMINAL_CAPABILITY_SCOPE_TYPE_UNDEFINED:
                return "TERMINAL_CAPABILITY_SCOPE_TYPE_UNDEFINED";
            case _TERMINAL_CAPABILITY_SCOPE_TYPE_CCPP:
                return "TERMINAL_CAPABILITY_SCOPE_TYPE_CCPP";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static TerminalCapabilityScopeType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof TerminalCapabilityScopeType)) {
            return false;
        }
        TerminalCapabilityScopeType terminalCapabilityScopeType = (TerminalCapabilityScopeType) o; 
        if(!(this.getValue() == terminalCapabilityScopeType.getValue())) {
            return false;
        }
        if (this.hashCode() != terminalCapabilityScopeType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // TerminalCapabilityScopeType

