//Source file: TriggeredTerminalCapability.java
//Date: March 2007
//Terminal Capability Interfaces and Data Types for 3GPP TS 29.198-07 V7.0.0

package org.csapi.jr.se.termcap;

/**
 * This interface represents a TriggeredTerminalCapability activity object.<BR>
 *
 */
public interface TriggeredTerminalCapability extends org.csapi.jr.se.Activity {

    /**
     * Returns a reference to the ExtendedTerminalCapabilities responsible for creation of the TriggeredTerminalCapability.
     *
     * @return  A reference to the ExtendedTerminalCapabilities responsible for creation of the TriggeredTerminalCapability.
     */
    org.csapi.jr.se.termcap.ExtendedTerminalCapabilities getExtendedTerminalCapabilities();

    /**
     * Adds a TriggeredTerminalCapabilityListener which is interested in events generated by the TriggeredTerminalCapability.
     *
     * @param  triggeredTerminalCapabilityListener  A reference to the TriggeredTerminalCapabilityListener which is to be added as
     *        a listener.
     */
    void addTriggeredTerminalCapabilityListener(org.csapi.jr.se.termcap.TriggeredTerminalCapabilityListener triggeredTerminalCapabilityListener);

    /**
     * Removes a TriggeredTerminalCapabilityListener which is no longer interested events generated by the TriggeredTerminalCapability.
     *
     * @param  triggeredTerminalCapabilityListener  A reference to the TriggeredTerminalCapabilityListener which is to be removed as
     *        a listener.
     */
    void removeTriggeredTerminalCapabilityListener(org.csapi.jr.se.termcap.TriggeredTerminalCapabilityListener triggeredTerminalCapabilityListener);

    /**
     * Invokes the triggeredTerminalCapabilityStartReq() method on the Parlay Gateway.
     */
    void triggeredTerminalCapabilityStartReq(
           org.csapi.jr.se.Address[] terminals,
           org.csapi.jr.se.termcap.TerminalCapabilityScope capabilityScope,
           int                             criteria)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InformationNotAvailableException,
       org.csapi.jr.se.InvalidInterfaceTypeException,
       org.csapi.jr.se.InvalidCriteriaException,
       org.csapi.jr.se.termcap.InvalidTerminalIdException;

    /**
     * Invokes the triggeredTerminalCapabilityStop() method on the Parlay Gateway.
     */
    void triggeredTerminalCapabilityStop()
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException;
}
